==> pmml-model-gwt-1.4.13.jar: org/dmg/pmml/nearest_neighbor/KNNInputs.java <==

package org.dmg.pmml.nearest_neighbor;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.Property;
import org.jpmml.model.annotations.ValueConstructor;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "knnInputs"
})
@XmlRootElement(name = "KNNInputs", namespace = "http://www.dmg.org/PMML-4_3")
@Added((org.dmg.pmml.Version.PMML_4_1))
@JsonAutoDetect(fieldVisibility = JsonAutoDetect.Visibility.ANY, getterVisibility = JsonAutoDetect.Visibility.NONE, isGetterVisibility = JsonAutoDetect.Visibility.NONE, setterVisibility = JsonAutoDetect.Visibility.NONE)
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "extensions",
    "knnInputs"
})
public class KNNInputs
    extends org.dmg.pmml.PMMLObject
    implements Iterable<KNNInput> , HasExtensions<KNNInputs>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "KNNInput", namespace = "http://www.dmg.org/PMML-4_3", required = true)
    @JsonProperty("KNNInput")
    private List<KNNInput> knnInputs;
    private final static long serialVersionUID = 67305489L;

    public KNNInputs() {
    }

    @ValueConstructor
    public KNNInputs(
        @Property("knnInputs")
        List<KNNInput> knnInputs) {
        this.knnInputs = knnInputs;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public KNNInputs addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public Iterator<KNNInput> iterator() {
        return getKNNInputs().iterator();
    }

    public boolean hasKNNInputs() {
        return ((this.knnInputs!= null)&&(this.knnInputs.size()> 0));
    }

    public List<KNNInput> getKNNInputs() {
        if (knnInputs == null) {
            knnInputs = new ArrayList<KNNInput>();
        }
        return this.knnInputs;
    }

    public KNNInputs addKNNInputs(KNNInput... knnInputs) {
        getKNNInputs().addAll(Arrays.asList(knnInputs));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasKNNInputs()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getKNNInputs());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.5.0.jar: org/dmg/pmml/nearest_neighbor/KNNInputs.java <==

package org.dmg.pmml.nearest_neighbor;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.Property;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "KNNInputs", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions",
    "knnInputs"
})
@Added((org.dmg.pmml.Version.PMML_4_1))
@JsonRootName("KNNInputs")
@JsonPropertyOrder({
    "extensions",
    "knnInputs"
})
public class KNNInputs
    extends org.dmg.pmml.PMMLObject
    implements Iterable<KNNInput> , HasExtensions<KNNInputs>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "KNNInput", namespace = "http://www.dmg.org/PMML-4_4", required = true)
    @JsonProperty("KNNInput")
    private List<KNNInput> knnInputs;
    private final static long serialVersionUID = 67371009L;

    public KNNInputs() {
    }

    @ValueConstructor
    public KNNInputs(
        @Property("knnInputs")
        List<KNNInput> knnInputs) {
        this.knnInputs = knnInputs;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public KNNInputs addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public Iterator<KNNInput> iterator() {
        return getKNNInputs().iterator();
    }

    public boolean hasKNNInputs() {
        return ((this.knnInputs!= null)&&(this.knnInputs.size()> 0));
    }

    public List<KNNInput> getKNNInputs() {
        if (knnInputs == null) {
            knnInputs = new ArrayList<KNNInput>();
        }
        return this.knnInputs;
    }

    public KNNInputs addKNNInputs(KNNInput... knnInputs) {
        getKNNInputs().addAll(Arrays.asList(knnInputs));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasKNNInputs()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getKNNInputs());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
